@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import os.path as osp
-import logging, subprocess, os, glob
+import logging, subprocess, os, glob, shutil
 
 def setup_logger(name='seutils'):
     if name in logging.Logger.manager.loggerDict:
@@ -318,3 +318,58 @@ def ls_root(paths):
                     )
     root_files.sort()
     return root_files
+
+
+def hadd(src, dst):
+    """
+    Calls `ls_root` on `src` in order to be able to pass directories, then hadds.
+    Needs ROOT env to be callable.
+    """
+    root_files = ls_root(src)
+    if not len(root_files):
+        raise RuntimeError('src {0} yielded 0 root files'.format(src))
+    cmd = ['hadd', dst] + root_files
+    try:
+        run_command(cmd)
+    except OSError as e:
+        if e.errno == 2:
+            logger.error('It looks like hadd is not on the path.')
+        else:
+            # Something else went wrong while trying to run `hadd`
+            raise
+
+
+# _______________________________________________________
+# Command line helpers
+
+MGM_ENV_KEY = 'SEU_DEFAULT_MGM'
+
+def cli_update_default_mgm(mgm):
+    if MGM_ENV_KEY in os.environ:
+        logger.warning(
+            'Setting default mgm to %s (previously: %s)',
+            mgm, os.environ[MGM_ENV_KEY]
+            )
+    else:
+        logger.warning('Setting default mgm to %s', mgm)
+    os.environ[MGM_ENV_KEY] = mgm
+
+def cli_detect_fnal():
+    mgm = None
+    if os.uname()[1].endswith('.fnal.gov'):
+        mgm = 'root://cmseos.fnal.gov'
+        logger.warning('Detected fnal.gov host; using mgm %s', mgm)
+    return mgm
+
+def cli_flexible_format(lfn, mgm=None):
+    if not lfn.startswith('root:') and not lfn.startswith('/'):
+        try:
+            prefix = '/store/user/' + os.environ['USER']
+            logger.warning('Pre-fixing %s', prefix)
+            lfn = os.path.join(prefix, lfn)
+        except KeyError:
+            pass
+    if lfn.startswith('root:'):
+        return format(lfn)
+    else:
+        return format(lfn, mgm)
